@@ -6,7 +6,7 @@ use warnings;
 use 5.010;
 
 # ABSTRACT: easier loading of a project's local libs
-our $VERSION = "1.004";
+our $VERSION = "1.005";
 
 use FindBin qw();
 use Carp qw(carp);
@@ -21,6 +21,7 @@ sub import {
     my @libdirs;
     my @locallibs;
     my @extra;
+    my @extra_with_local;
     foreach my $d (@_) {
         if ( $d =~ /^local::lib=([\S]+)/ ) {
             push( @libdirs,   $1 );
@@ -29,6 +30,9 @@ sub import {
         elsif ( $d =~ /^extra=([\S]+)/ ) {
             @extra = split( /[,;]/, $1 );
         }
+        elsif ( $d =~ /^extra_with_local=([\S]+)/ ) {
+            @extra_with_local = split( /[,;]/, $1 );
+        }
         else {
             push( @libdirs, $d );
         }
@@ -54,6 +58,8 @@ sub import {
             if @locallibs;
         lib->import( map { catdir( $ROOT, $_ ) } @libdirs ) if @libdirs;
         __PACKAGE__->load_extra(@extra) if @extra;
+        __PACKAGE__->load_extra_with_local(@extra_with_local)
+            if @extra_with_local;
     }
     else {
         carp "Could not find root dir containing " . join( ', ', @libdirs );
@@ -79,6 +85,34 @@ sub load_extra {
     }
 }
 
+sub load_extra_with_local {
+    my $class  = shift;
+    my @extras = @_;
+
+    my @parts = splitdir($ROOT);
+    pop(@parts);
+    my $parent = catdir(@parts);
+
+    foreach my $d (@extras) {
+        my $extra = catdir( $parent, $d, 'lib' );
+        if ( -d $extra ) {
+            push( @INC, $extra );
+            my $extra_local = catdir( $parent, $d, 'local' );
+            if ( -d $extra_local ) {
+                local::lib->import($extra_local);
+            }
+            else {
+                carp
+                    "Cannot load local::lib in extra $d, directory $extra_local does not exist";
+
+            }
+        }
+        else {
+            carp "Cannot load_extra $d, directory $extra does not exist";
+        }
+    }
+}
+
 42;
 
 __END__
@@ -93,7 +127,7 @@ lib::projectroot - easier loading of a project's local libs
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -122,6 +156,9 @@ version 1.004
   # if you want to know where the project-root is:
   say lib::projectroot::ROOT;  # /home/domm/jobs/Some-Project
 
+  # also load local::libs installed in extras
+  use lib::projectroot qw(lib local::lib=local extra_with_local=Your-OtherModule,Dark-PAN);
+
 =head1 DESCRIPTION
 
 I'm usually using a setup like this:
@@ -182,6 +219,15 @@ You can also define extra dists directly while loading C<lib::projectroot>:
       extra=MyHelperStuff,CoolLib-NotYetOnCPAN
   );
 
+If your extra dists themselves have deps which are installed into their C<local::lib>, you can add those via C<extra_with_local>:
+
+  use lib::projectroot qw(
+      lib
+      local::lib=local
+      extra=MyHelperStuff
+      extra_with_local=CoolLib-NotYetOnCPAN
+  );
+
 You can access C<$lib::projectroot::ROOT> if you need to know where the projectroot actually is located (e.g. to load some assets)
 
 =head1 TODOs
@@ -192,8 +238,6 @@ Some ideas for future releases:
 
 =item * what happens if C<$PERL5LIB> is already set?
 
-=item * add C<local::lib> dirs of extras (i.e. if DarkPAN also uses C<local::lib> to install its deps)
-
 =item * think about the security issues raised by Abraxxa (http://prepan.org/module/nY4oajhgzJN 2014-12-02 18:42:07)
 
 =back
